@@ -26,7 +26,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.35 1999/10/20 18:55:53 windl Exp $
+ * $Id: enable_pps.c,v 1.36 1999/10/29 22:09:22 windl Exp $
  */
 #include	<unistd.h>
 #include	<stdlib.h>
@@ -84,7 +84,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.35 1999/10/20 18:55:53 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.36 1999/10/29 22:09:22 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -656,6 +656,9 @@ static	void	usage(void)
 #endif
 		"\t-O\tdon't adjust offset in monitoring loop\n"
 		"\t-oXY\tSet PPS API offset for `X' events (a|c) to `Y'ns\n"
+#ifdef MOD_PPSMAX
+		"\t-PX\tset PPS shiftmax to `X'\n"
+#endif
 		"\t-S\tdon't adjust status in monitoring loop\n"
 		"\t-t{0|a|c|b}[h]\ttrigger for event: off|assert|clear|both\n"
 		);
@@ -689,7 +692,7 @@ int	main(int argc, char *argv[])
 	uname(&un);
 	printf(". Now running %s %s)\n", un.sysname, un.release);
 	parm.mode = PPS_TSFMT_TSPEC;	/* set default flags */
-	while ( (ch = getopt(argc, argv, "CE:eFJjkMNOo:St:")) != -1 )
+	while ( (ch = getopt(argc, argv, "CE:eFJjkMNOo:P:St:")) != -1 )
 	{
 		switch ( ch )
 		{
@@ -737,9 +740,6 @@ int	main(int argc, char *argv[])
 		case 'O':	/* don't adjust offset */
 			options = BITS_ON(options, OPT_NO_OFFSET);
 			break;
-		case 'S':	/* don't adjust time status */
-			options = BITS_ON(options, OPT_NO_STATUS);
-			break;
 		case 'o':
 			switch (optarg[0])
 			{
@@ -762,6 +762,16 @@ int	main(int argc, char *argv[])
 				exit(1);
 			}
 			break;
+#ifdef MOD_PPSMAX
+		case 'P':
+			ci.tx.shift = strtol(optarg, NULL, 10);
+			ci.tx.modes = MOD_PPSMAX;
+			verbose_adjtimex("MOD_PPSMAX", 0, &ci);
+			break;
+#endif
+		case 'S':	/* don't adjust time status */
+			options = BITS_ON(options, OPT_NO_STATUS);
+			break;
 		case 't':	/* select desired edge of the pulse */
 			trigger = optarg[0];
 			switch ( trigger )
